Calculate and plot item information functions for a fitted IRT model.
Arguments
- fit
A fitted IRT model object.
- ...
Additional arguments passed to
item_infoor the plot method.
Calculate and plot item information functions for a fitted IRT model.
A fitted IRT model object.
Additional arguments passed to item_info or the plot method.