Skip to contents

Calculate and plot marginal means for a fitted model.

Usage

plot_lsmeans(fit, specs, ...)

Arguments

fit

A fitted model object (e.g. `Classic_Fit`).

specs

Character vector specifying the variables for which marginal means are calculated.

...

Additional arguments passed to lsmeans or the plot method.

Value

Invisibly returns the plotted object.