Calculate and plot test information function for a fitted IRT model.
Arguments
- fit
A fitted IRT model object.
- ...
Additional arguments passed to
test_infoor the plot method.
Calculate and plot test information function for a fitted IRT model.
A fitted IRT model object.
Additional arguments passed to test_info or the plot method.