Skip to contents

`prior_flat()` specifies that no additional prior density is added by the wrapper. This is the only prior type allowed for `classic()`.

Usage

prior_flat()

Value

A list with class `"rtmb_prior"` and `type = "flat"`.