Calculate and plot marginal means for a fitted model.
Arguments
- fit
A fitted model object (e.g. `Classic_Fit`).
- specs
Character vector specifying the variables for which marginal means are calculated.
- ...
Additional arguments passed to
lsmeansor the plot method.