`prior_flat()` specifies that no additional prior density is added by the wrapper. This is the only prior type allowed for `classic()`.
`prior_flat()` specifies that no additional prior density is added by the wrapper. This is the only prior type allowed for `classic()`.