Before passing data to `rtmb_model`, it checks for the presence of R-specific data types (such as data.frame) and missing values, and outputs errors or warnings accordingly.
Before passing data to `rtmb_model`, it checks for the presence of R-specific data types (such as data.frame) and missing values, and outputs errors or warnings accordingly.